# TCGAMaxim

This is a python library for TCGA raw data process.

Contains a meta process tool `TCGAMaxim.meta`, which loads meta data and
provides convenient iteration function.

Provides svs data process functions.
